@@ -311,7 +311,7 @@ class TestPypandoc(unittest.TestCase):
     def test_conversion_with_python_filter(self):
         markdown_source = "**Here comes the content.**"
         python_source = '''\
-        #!/usr/bin/env python
+        #!{0}
 
         """
         Pandoc filter to convert all regular text to uppercase.
@@ -328,6 +328,8 @@ class TestPypandoc(unittest.TestCase):
             toJSONFilter(caps)
         '''
         python_source = textwrap.dedent(python_source)
+        python_source.format(sys.executable)
+        
         with closed_tempfile(".py", python_source) as tempfile:
             output = pypandoc.convert_text(
                 markdown_source, to='html', format='md', outputfile=None, filters=tempfile
@@ -362,7 +364,7 @@ class TestPypandoc(unittest.TestCase):
         lua = textwrap.dedent(lua)
 
         python = """\
-        #!/usr/bin/env python
+        #!{0}
 
         from pandocfilters import toJSONFilter, Para, Str
 
@@ -375,6 +377,7 @@ class TestPypandoc(unittest.TestCase):
         
         """
         python = textwrap.dedent(python)
+        python.format(sys.executable)
 
         with closed_tempfile(".lua", lua.format(1)) as temp1, closed_tempfile(".py", python.format(2)) as temp2:
             with closed_tempfile(".lua", lua.format(3)) as temp3, closed_tempfile(".py", python.format(4)) as temp4:
